@@ -11,6 +11,8 @@ class RawCustomField(TypedDict):
 class RawTask(TypedDict):
     id: str
     description: str
+    status: dict
+    due_date: str  # "timestamp"
     url: str
     name: str
     type: str
