@@ -1,8 +1,8 @@
 import re
 from typing import Any
 
-from .base import ValidationError
 from .string import StringValidator
+from ..exceptions.validators import ValidationError
 from ..types import RawCustomField
 
 
@@ -14,11 +14,7 @@ class EmailValidator(StringValidator):
         return bool(re.fullmatch(cls.EMAIL_REGEX, value))
 
     @classmethod
-    def validate(
-        cls,
-        value: Any,
-        raw_field: RawCustomField
-    ) -> None:
+    def validate(cls, value: Any, raw_field: RawCustomField) -> None:
         super().validate(value, raw_field)
 
         if not cls.__is_good_email(value):
